# PyResult

A simple Python library that implements Rust-like `Result` and `Option` types.

## Installation

```bash
pip install rs-result
```

## Usage

## Documentation

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
